<template>
  <div>
    <el-form :model="formData" :rules="formRules" ref="dataForm" label-width="120px">
      <el-row type="flex" justify="end">
        <el-button-group style="display: flex;margin-bottom: 15px; margin-right: 50px">
          <el-button type="primary" @click.native="saveOrder('1')" :loading="loading">草稿保存</el-button>
          <el-button type="primary" @click.native="saveOrder('2')" :loading="loading">提交单据</el-button>
        </el-button-group>
      </el-row>

      <el-card style="margin-top: -5px;">
        <el-row>
          <el-col :span="11">
            <el-form-item label="单据号:" prop="billNo">
              <el-input v-model="formData.billNo" auto-complete="off" :disabled="true"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="单据时间:" prop="billdate">
              <el-date-picker
                v-model="formData.billDate"
                type="datetime"
                placeholder="选择日期"
                style="width: 100%"
                :clearable="false"
                value-format="yyyy-MM-dd HH:mm:ss"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="11">
            <el-form-item label="到货仓库:" prop="invCode">
              <el-select v-model="formData.invCode" @change="setDeptCode" placeholder="到货仓库信息" style="width: 100%"
                         clearable>
                <el-option
                  v-for="item in invCodeList"
                  :key="item.name"
                  :label="item.name"
                  :value="item.code">
                  <span style="float: left">{{ item.name }}</span>
                  <span style="float: right; color: #8492a6; font-size: 13px">{{ item.warehouseName }}</span>
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item prop="fromCorp"
                          label="供应商:">
              <el-select
                v-model="formData.supId"
                filterable
                remote
                clearable
                reserve-keyword
                style="width: 100%"
                placeholder="请输入往来单位"
                :remote-method="findMethod"
                :loading="loading"
              >
                <el-option
                  v-for="item in fromOptions"
                  :key="item.erpId"
                  :label="item.name"
                  :value="item.erpId"
                >
                  <span style="float: left">{{ item.name }}</span>
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="11">
            <el-form-item label="备注说明:" prop="billNo">
              <el-input v-model="formData.remark" auto-complete="off" type="textarea" autosize></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="11" v-show="formData.status==4">
            <el-form-item label="拒绝原因:">
              <el-input v-model="formData.auditRemark" auto-complete="off" :disabled="true"></el-input>
            </el-form-item>
          </el-col>

        </el-row>
      </el-card>

      <el-card>
        <el-row type="flex" justify="end">
          <el-button-group style="display: flex">
            <el-button-group style="display: flex;margin-bottom: 15px; margin-right: 50px">
              <el-button type="primary" @click.native.stop="selectProductFunction()" :loading="loading">产品录入</el-button>
              <el-button type="primary" :loading="loading" @click.native.stop="selectApply()">选入送货单据</el-button>
            </el-button-group>


          </el-button-group>
        </el-row>
        <el-table v-loading="loading" :data="codeArray" style="width: 100%;" :row-class-name="tableRowClassName" border
                  highlight-current-row max-height="300" height="300" ref="multipleTable">
          <el-table-column label="序号" type="index" width="50"></el-table-column>
          <el-table-column label="产品通用名" prop="productName" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column label="规格型号" prop="spec" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column width="150" label="批次号">
            <template slot-scope="scope">
              <el-input v-model="scope.row.batchNo"
                        :disabled="scope.row.index !== selectedIndex"
                        @input="scope.row.batchNo =scope.row.batchNo.replace(/[\W]/g, '')"
                        ref='inputBatchNoRef'
                        placeholder="请输入批次号"></el-input>
            </template>
          </el-table-column>
          <el-table-column width="150" label="生产日期(yyMMdd)">
            <template slot-scope="scope">
              <el-input v-model="scope.row.productDate" auto-complete="off"
                        oninput="if(value.length>6)value=value.slice(0,6)"
                        :disabled="scope.row.index !== selectedIndex"
                        type="number"
              ></el-input>
            </template>
          </el-table-column>
          <el-table-column width="150" label="失效日期(yyMMdd)">
            <template slot-scope="scope">
              <el-input v-model="scope.row.expireDate" auto-complete="off"
                        oninput="if(value.length>6)value=value.slice(0,6)"
                        :disabled="scope.row.index !== selectedIndex"
                        type="number"
              ></el-input>
            </template>
          </el-table-column>
          <el-table-column label="送货数量" prop="count" width="120" show-overflow-tooltip></el-table-column>
          <el-table-column width="120" label="到货数量">
            <template slot-scope="scope">
              <el-input size="small" v-model="scope.row.arrivalCount"
                        placeholder="请输入数量" style="width: 80%"
                        type='number'
                        @change="tableCountChange(scope.row)"
                        :disabled="scope.row.index !== selectedIndex"
                        oninput="value=value.replace(/[^\d]/g,'')"></el-input>
            </template>
          </el-table-column>
          <el-table-column label="供应商" prop="supName" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column label="注册/备案凭证号" prop="zczbhhzbapzbh" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column label="生产厂家" prop="manufactory" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column label="医疗器械注册人" prop="ylqxzcrbarmc" width="150" show-overflow-tooltip></el-table-column>
          <el-table-column label="操作" width="120" fixed="right">
            <template slot-scope="scope">
              <el-button type="text" size="small" :disabled="scope.row.index === selectedIndex" @click.stop="true"
                         @click.native="rowChange(scope.row)">编辑
              </el-button>
              <el-button type="text" size="small" @click.stop="true"
                         @click.native="deleteCodeArray(scope.$index, scope.row)">删除
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </el-card>
    </el-form>

    <el-dialog
      title="产品录入"
      :visible.sync="selectProductVisible"
      :close-on-click-modal="false"
      :close-on-press-escape="false"
      width="80%"
      v-if="selectProductVisible"
      :append-to-body='true'
    >
      <purOrderProducts
        :closeDialog="closeDialogC2"
        :purType="1"
        :pId="pId"
        :data="thisData"
        :customerId="formData.supId"
      ></purOrderProducts>
    </el-dialog>

    <el-dialog
      title="送货单选入"
      :visible.sync="selectApplyVisible"
      :close-on-click-modal="false"
      :close-on-press-escape="false"
      width="80%"
      append-to-body
      v-if="selectApplyVisible"
    >
      <select-plan-list-dialog
        :data="thisData"
        :pId="pId"
        :customer-id="formData.supId"
        :closeDialog="closeDialogC2"
      ></select-plan-list-dialog>
    </el-dialog>
  </div>
</template>

<script>
import purOrderProducts from "@/views/purchase/purArrival/purArrivalSelectProduct";
import {
  inserThrOrderWeb,
  delOrderDetail,
  listOrderDetail,
  addOrderId,
  selectOrderDetail,
  updateDetail
} from "@/api/purchase/purArrival";
import {findInvByUser} from "@/api/system/invSubWarehouse";
import SelectPlanListDialog from "@/views/purchase/purDelivery/DialogSelectDeliveryList";
import {getBasicUnitMaintains} from "@/api/basic/basicUnitMaintain";
import {isBlank} from "@/utils/strUtil";


export default {
  name: "idQuery",
  props: {
    closeDialog: {
      type: Function,
      required: true,
    },
    idQuery: {
      type: Object,
      required: true,
    },
    isChang: {
      type: Boolean,
      required: true,
    },
  },
  data() {
    return {
      code: "",
      query: {
        orderIdFk: "",
        page: 1,
        limit: 10,
      },
      formData: {
        id: null,
        billNo: null,
        billDate: "",
        remark: "",
        deptCode: null,
        locStorageCode: null,
        invWarehouseCode: null,
      },
      pId: null,
      formRules: {},
      codeArray: [],
      fromOptions: [],
      total: 0,
      loading: false,
      index: null,
      formLoading: false,
      formVisible: false,
      deleteLoading: false,
      orderNo: null,
      statusMap: {
        1: "草稿",
        2: "未审核",
        3: "已审核",
      },
      typeMap: {
        1: "预入库",
        2: "普通采购",
      },
      orderEditor: true,
      sOptions: [],
      sValue: [],
      sList: [],
      sLoading: false,
      busTypes: [],
      currentRow: {},
      selectedIndex: "",
      selectProductVisible: false,
      thisData: {},
      storageList: [],
      invCodeList: [],
      invQueryData: {},
      selectApplyVisible: false
    };
  },
  watch: {
    isChang: function () {
      this.$emit("cancelDialog", this.pId);
    },
  },
  components: {
    purOrderProducts,
    SelectPlanListDialog
  },
  methods: {
    saveOrder(status) {

      this.tableCountChange(this.currentRow);

      this.$refs["dataForm"].validate(valid => {
        if (valid) {
          if (this.codeArray.length < 1) {
            this.$message.warning('未添加产品');
            return;
          }
          if (status === '2') {

            if (this.formData.billDate == "" || this.formData.billDate == null) {
              return this.$message.error("单据日期不能为空！");
            }
            if (this.formData.invCode == "" || this.formData.invCode == null) {
              return this.$message.error("采购仓库不能为空！");
            }
            for (let i = 0; i < this.codeArray.length; i++) {
              if (this.$isBlank(this.codeArray[i].count) || this.codeArray[i].count == "0") {
                return this.$message.error('单据数量不能为0');
              }
            }
          }
          if (status == "1") {
            this.submitFunction(status);
          } else {
            let tip = "是否确定提交订单?";
            this.$confirm(tip, "提示", {
              confirmButtonText: "确定",
              cancelButtonText: "取消",
              type: "warning",
            }).then(() => {
              this.submitFunction(status);
            }).catch(() => {
              this.loading = false;
            });
          }
        }
      });
    },
    submitFunction(status) {
      let tMessage = status === '1' ? '保存' : '提交';
      this.loading = true;
      this.formData.id = this.pId;
      let tQuery = {
        editStatus: status,
        purArrivalEntity: this.formData,
        subErpOrders: this.codeArray,
        type: 1,
      }
      inserThrOrderWeb(tQuery)
        .then(response => {
          this.loading = false;
          if (response.code === 20000) {
            this.$message.success(tMessage + "成功");
            this.closeDialog(true);
          } else {
            this.$message.error(response.message);
          }
        })
        .catch(() => {
          this.loading = false;
        })
    },
    selectProductFunction() {
      if (isBlank(this.formData.supId)) {
        this.$message.error("请先选择供应商！");
        return;
      }
      this.selectProductVisible = true;
      //当父id为空的时候生成id
      if (this.pId == null) {
        addOrderId().then(response => {
          if (response.code === 20000) {
            this.pId = response.data
          }
        }).catch(() => {
          this.loading = false;
        })
      }
      this.thisData.stockOrderLists = this.codeArray;
    },

    //获取往来单位候选列表
    findMethod(query) {
      this.fromOptions = [];
      let cQuery = {
        key: query,
        corpType: 2,
        outType: null,
        page: 1,
        limit: 20
      };
      getBasicUnitMaintains(cQuery)
        .then((response) => {
          this.loading = false;
          this.fromOptions = response.data.list || [];
        })
        .catch(() => {
          this.loading = false;
        });
    },


    setDeptCode(obj) {
      this.formData.deptCode = this.invCodeList.find(item => item.code == obj).parentId;
    },
    closeDialogC2() {
      this.selectProductVisible = false;
      this.selectApplyVisible = false;
      this.query = {
        orderIdFk: this.pId
      }
      selectOrderDetail(this.query) //查找该单号下的所有条码
        .then((response) => {
          console.log(response)
          this.codeArray = response.data.list || [];
          this.total = response.data.total || 0;
          this.loading = false;
        })
        .catch(() => {
          this.loading = false;
          this.list = [];
          this.total = 0;
        });
    },
    rowChange(val) {
      this.tableCountChange(this.currentRow);
      this.currentRow = val;
      this.selectedIndex = val.index;
    },
    tableCountChange(row) {
      if (this.$isNotBlank(row)) {
        updateDetail(this.currentRow);
      }
    },
    tableRowClassName({row, rowIndex}) {
      row.index = rowIndex;
    },
    // 刷新表单
    resetForm() {
      if (this.$refs["dataForm"]) {
        // 清空验证信息表单
        this.$refs["dataForm"].clearValidate();
        // 刷新表单
        this.$refs["dataForm"].resetFields();
        this.getList();
      }
    },
    deleteCodeArray(index, row) {
      this.$confirm("此操作将永久删除该数据, 是否继续?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      }).then(() => {
        this.$refs.multipleTable.setCurrentRow();
        this.currentRow = {};
        this.selectedIndex = "";

        if (this.orderEditor) {
          this.detailLoading = true;
          if (this.$isNotBlank(row.id)) {
            let delIds = [];
            delIds.push(row.id)
            delOrderDetail(delIds)
              .then(response => {
                this.detailLoading = false;
                if (response.code === 20000) {
                  this.$message.success(response.data);
                  // this.getStockOrderDetailList();
                  this.codeArray.splice(index, 1);
                } else {
                  this.$message.error(response.message);
                }
              })
              .catch(() => {
                this.detailLoading = false;
              })
          } else {
            this.$message.success('删除成功');
            this.codeArray.splice(index, 1);
          }
        } else {
          this.$message.success('删除成功');
          this.codeArray.splice(index, 1);
        }
      }).catch(() => {

      });
    },
    getStockOrderDetailList() {
      this.loading = true;
      listOrderDetail(this.query) //查找该单号下的所有条码
        .then((response) => {
          console.log(response)
          this.codeArray = response.data.list || [];
          this.total = response.data.total || 0;
          this.loading = false;
        })
        .catch(() => {
          this.loading = false;
          this.list = [];
          this.total = 0;
        });
    },
    findSubInvs() {
      this.invCodeList = [];
      findInvByUser()
        .then((response) => {
          this.invCodeList = response.data || [];
          if (this.invCodeList != null && this.invCodeList.length == 1) {
            this.formData.invCode = this.invCodeList[0].code;
          }
        })
        .catch(() => {
        });
    },
    selectApply() {
      if (isBlank(this.formData.supId)) {
        this.$message.error("请先选择供应商！");
        return;
      }
      this.selectApplyVisible = true;
      //当父id为空的时候生成id
      if (this.pId == null) {
        addOrderId().then(response => {
          if (response.code === 20000) {
            this.pId = response.data
          }
        }).catch(() => {
          this.loading = false;
        })
      }
    },
  },
  filters: {},
  mounted() {
    document.body.ondrop = function (event) {
      event.preventDefault();
      event.stopPropagation();
    };
  },
  created() {

    if (this.$isNotBlank(this.idQuery.id)) {
      this.query.limit = 100;
      this.pId = this.idQuery.id;
      this.query.orderIdFk = this.idQuery.id;
      this.formData = this.idQuery.formData;
      this.orderEditor = true;
      this.sValue = this.formData.corpName;
      this.findMethod(this.formData.supId);
      this.getStockOrderDetailList();
    } else {
      this.formData = {
        id: null,
        billNo: null,
        billDate: "",
        remark: "",
        deptCode: null,
        incCode: null,
      };
      this.orderEditor = false;
      this.findMethod();
    }
    this.findSubInvs();
    this.codeArray = [];
  },
};
</script>
<style>

.ao-text {
  width: 100%;
  font-size: 13px;
  font-family: "Microsoft YaHei";
  float: right;
  text-align: right;
  margin-top: 10px;
}

</style>



